#!/bin/bash

function test {
	if [ ! -e "$1" ]; then
		echo $2 \"$1\" does not exist.
		exit
	fi
}

if [ "$1" == "--help" ]; then
	echo Fix flexpoller archive caused by \"expiry\" issue.
	echo
	echo Usage: fix_flexpoller_expiry.sh \<start year\>-\<month\> \<end year\>-\<month\>
	echo
	echo "Example: Fix flexpoller archive starting from January 2015 to March 2015."
	echo 
	echo "	fix_flexpoller_expiry.sh 2015-1 2015-3"
	echo
	echo Please take note that \"date\" is not included.
	exit
fi

if [ -z "$1" ] || [ -z "$2" ]; then
	echo Missing parameters. --help for more details.
	exit
fi

# LOAD OPENIT-CFG-SHENV
openitenv="/tmp/openit-cfg-shenv"
test $openitenv
. $openitenv
test "$ARCHIVE_DIR" "Archive directory"
flexpollerdir="$ARCHIVE_DIR/license/flexpoller"
test $flexpollerdir "Flexpoller directory"
cd $flexpollerdir


# READ PARAMS
START_YEAR=$(echo $1 | cut -d - -f 1)
START_MONTH=$(echo $1 | cut -d - -f 2)
END_YEAR=$(echo $2 | cut -d - -f 1)
END_MONTH=$(echo $2 | cut -d - -f 2)

if [ "$START_YEAR-$START_MONTH" != "$1" ] && [ "$END_YEAR-$END_MONTH" != "$2" ]; then
	echo Incorrect parameters. --help for more details.
	exit
fi

echo "Fixing flexpoller archive from $START_YEAR/$START_MONTH to $END_YEAR/$END_MONTH..."

years="*"
for year in $years; do
	if [ $year -ge $START_YEAR ] && [ $year -le $END_YEAR ]; then
		cd $year

		first_month=1
		last_month=31
		if [ $year -eq $START_YEAR ]; then
			first_month=$START_MONTH
		fi
		if [ $year -eq $END_YEAR ]; then
			last_month=$END_MONTH
		fi

		months="*"
		for month in $months; do
			if [ $month -ge $first_month ] && [ $month -le $last_month ]; then
				cd $month

				days="*"
				for day in $days; do
					cd $day

					# DELETE FLAB FILES
					rm -rf *FLAB*
					rm -rf EVENTS*

					# ONLY CHOOSE RAW FLEXPOLLER DATA
					files=$(zgrep -l ", expiry" *.in.gz | grep "LMSTAT" | grep -v "FLAB")
					for file in $files; do
						
						# MAIN LOGIC
						gzip -d -c "$file" | awk '/, expiry/ { gsub(/, expiry: [^:,]*/, "") }{ print }' | gzip -c > "$file.tmp"
						mv "$file" "$file.old"
						mv "$file.tmp" "$file"
						# END MAIN LOGIC

					done

					cd ../ # day
				done

				cd ../ # month
			fi
		done

		cd ../ # year
	fi
done

echo Done. Please run flab to rebuild flab files.
echo
echo To run flab, please enter the command below.
echo "    /opt/openit/bin/flab -c /var/opt/openit/etc/daft.conf $START_YEAR-$START_MONTH-1 $END_YEAR-$END_MONTH-31"
